<?php
namespace VamtamElementor\Widgets\CallToAction;

// Extending the Call To Action widget.

if ( vamtam_theme_supports( 'call-to-action--estudiar-cta-style' ) ) {
	function render_content( $content, $widget ) {
		if ( 'call-to-action' === $widget->get_name() ) {
			$settings = $widget->get_settings();
			if ( ! empty( $settings['use_theme_cta_style'] ) ) {
				$icon = '<i aria-hidden="true" class="vamtamtheme- vamtam-theme-arrow-right"></i>';
				// Inject theme icon.
				$content = preg_replace( '/(<div class="elementor-cta__button-wrapper elementor-cta__content-item elementor-content-item[^>]*>[^~]*?)(<\/div>)/s', '$1' . $icon . '$2', $content );
			}
		}

		return $content;
	}
	add_filter( 'elementor/widget/render_content', __NAMESPACE__ . '\render_content', 10, 2 );

	function use_theme_cta_style_control( $controls_manager, $widget ) {
		$widget->start_injection( [
			'of' => 'min-height',
			'at' => 'before',
		] );
		$widget->add_control(
			'use_theme_cta_style',
			[
				'label' => __( 'Use Theme Style', 'vamtam-elementor-integration' ),
				'type' => $controls_manager::SWITCHER,
				'prefix_class' => 'vamtam-has-',
				'return_value' => 'theme-cta-style',
				'default' => 'theme-cta-style',
				'render_type' => 'template',
			]
		);
		$widget->end_injection();
	}
	function update_alignment_control( $controls_manager, $widget ) {
		// Alignment.
		\Vamtam_Elementor_Utils::add_control_options( $controls_manager, $widget, 'alignment', [
			'prefix_class' => 'vamtam-elementor-cta-align-',
		] );
	}
	// Style - Box Section
	function box_style_before_section_end( $widget ) {
		$controls_manager = \Elementor\Plugin::instance()->controls_manager;
		use_theme_cta_style_control( $controls_manager, $widget );
		update_alignment_control( $controls_manager, $widget );
	}
	add_action( 'elementor/element/call-to-action/box_style/before_section_end', __NAMESPACE__ . '\box_style_before_section_end' );

	function update_button_color_controls( $controls_manager, $widget ) {
		// Button Color.
		\Vamtam_Elementor_Utils::add_control_options( $controls_manager, $widget, 'button_color', [
			'selectors' => [
				'{{WRAPPER}} .elementor-cta__button ~ i.vamtamtheme-' => 'color: {{VALUE}};',
			],
		] );
		// Button Hover Color.
		\Vamtam_Elementor_Utils::add_control_options( $controls_manager, $widget, 'button_color_hover', [
			'selectors' => [
				'{{WRAPPER}} .elementor-cta:hover .elementor-cta__button ~ i.vamtamtheme-' => 'color: {{VALUE}};',
			],
		] );
	}	
	// Style - Content Section
	function section_content_style_before_section_end( $widget ) {
		$controls_manager = \Elementor\Plugin::instance()->controls_manager;
		update_button_color_controls( $controls_manager, $widget );
	}
	add_action( 'elementor/element/call-to-action/section_content_style/before_section_end', __NAMESPACE__ . '\section_content_style_before_section_end' );
}

if ( vamtam_theme_supports( 'call-to-action--graphic-element-hover-color' ) ) {
	function add_icon_hover_control( $controls_manager, $widget ) {
		$widget->start_injection( [
			'of' => 'icon_primary_color',
		] );
		$widget->add_control(
			'icon_hover_color',
			[
				'label' => __( 'Hover Color', 'vamtam-elementor-integration' ),
				'type' => $controls_manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .elementor-cta:hover .elementor-view-stacked .elementor-icon' => 'background-color: {{VALUE}}',
					'{{WRAPPER}} .elementor-cta:hover .elementor-view-stacked .elementor-icon svg' => 'stroke: {{VALUE}}',
					'{{WRAPPER}} .elementor-cta:hover .elementor-view-framed .elementor-icon, {{WRAPPER}} .elementor-cta:hover .elementor-view-default .elementor-icon' => 'color: {{VALUE}}; border-color: {{VALUE}}',
					'{{WRAPPER}} .elementor-cta:hover .elementor-view-framed .elementor-icon, {{WRAPPER}} .elementor-cta:hover .elementor-view-default .elementor-icon svg' => 'fill: {{VALUE}};',
				],
				'condition' => [
					'graphic_element' => 'icon',
				],
			]
		);
		$widget->end_injection();
	}

	// Style - Graphic Element Section
	function graphic_element_style_before_section_end( $widget ) {
		$controls_manager = \Elementor\Plugin::instance()->controls_manager;
		add_icon_hover_control( $controls_manager, $widget );
	}
	add_action( 'elementor/element/call-to-action/graphic_element_style/before_section_end', __NAMESPACE__ . '\graphic_element_style_before_section_end' );
}